#ifndef __NEWCOMPLEARN_H
#define __NEWCOMPLEARN_H

#ifdef __cplusplus
extern "C" {
#endif

#include "complearn-real-compressor-adaptor.h"
#include "real-compressor.h"
#include "complearn-compressor-driver.h"
#include "complearn-external-file-compressor.h"
#include "util.h"
#include "complearn-rczlib.h"
#include "clconfig.h"
#include "cloutput.h"
#include "complearn-rcbzlib.h"
#include "complearn-rcgzip.h"
#include "complearn-vcblocksort.h"
#include "complearn-ncd.h"
#include "complearn-environment.h"

#ifdef __cplusplus
}
#endif

#endif
